[lld] r315415 - Rename processCommands -> processSectionCommands.
Rui Ueyama via llvm-commits
llvm-commits at lists.llvm.org
Tue Oct 10 19:28:28 PDT 2017
Author: ruiu
Date: Tue Oct 10 19:28:28 2017
New Revision: 315415
URL: http://llvm.org/viewvc/llvm-project?rev=315415&view=rev
Log:
Rename processCommands -> processSectionCommands.
Modified:
lld/trunk/ELF/LinkerScript.cpp
lld/trunk/ELF/LinkerScript.h
lld/trunk/ELF/OutputSections.h
lld/trunk/ELF/Writer.cpp
Modified: lld/trunk/ELF/LinkerScript.cpp
URL: http://llvm.org/viewvc/llvm-project/lld/trunk/ELF/LinkerScript.cpp?rev=315415&r1=315414&r2=315415&view=diff
==============================================================================
--- lld/trunk/ELF/OutputSections.h (original)
+++ lld/trunk/ELF/OutputSections.h Tue Oct 10 19:28:28 2017
@@ -46,6 +46,7 @@ public:
static bool classof(const SectionBase *S) {
return S->kind() == SectionBase::Output;
}
+
static bool classof(const BaseCommand *C);
uint64_t getLMA() const { return Addr + LMAOffset; }
Modified: lld/trunk/ELF/Writer.cpp
URL: http://llvm.org/viewvc/llvm-project/lld/trunk/ELF/Writer.cpp?rev=315415&r1=315414&r2=315415&view=diff
==============================================================================
--- lld/trunk/ELF/Writer.cpp (original)
+++ lld/trunk/ELF/Writer.cpp Tue Oct 10 19:28:28 2017
@@ -163,7 +163,7 @@ template <class ELFT> void Writer<ELFT>:
// Create output sections.
if (Script->HasSectionsCommand) {
// If linker script contains SECTIONS commands, let it create sections.
- Script->processCommands(Factory);
+ Script->processSectionCommands(Factory);
// Linker scripts may have left some input sections unassigned.
// Assign such sections using the default rule.
@@ -173,7 +173,7 @@ template <class ELFT> void Writer<ELFT>:
// output sections by default rules. We still need to give the
// linker script a chance to run, because it might contain
// non-SECTIONS commands such as ASSERT.
- Script->processCommands(Factory);
+ Script->processSectionCommands(Factory);
createSections();
}
More information about the llvm-commits
mailing list
--- lld/trunk/ELF/LinkerScript.cpp (original)
+++ lld/trunk/ELF/LinkerScript.cpp Tue Oct 10 19:28:28 2017
@@ -114,8 +114,8 @@ void LinkerScript::setDot(Expr E, const
CurAddressState->OutSec->Size = Dot - CurAddressState->OutSec->Addr;
}
// This function is called from processCommands, while we are
// fixing the output section layout.
void LinkerScript::addSymbol(SymbolAssignment *Cmd) {
if (Cmd->Name == ".")
return;
@@ -337,7 +337,7 @@ LinkerScript::createInputSectionList(Out
return Ret;
}
-void LinkerScript::processCommands(OutputSectionFactory &Factory) {
+void LinkerScript::processSectionCommands(OutputSectionFactory &Factory) {
// A symbol can be assigned before any section is mentioned in the linker
// script. In an DSO, the symbol values are addresses, so the only important
// section values are:
@@ -114,8 +114,8 @@ void LinkerScript::setDot(Expr E, const
CurAddressState->OutSec->Size = Dot - CurAddressState->OutSec->Addr;
}
-// This function is called from processCommands, while we are
-// fixing the output section layout.
+// This function is called from processSectionCommands,
+// while we are fixing the output section layout.
void LinkerScript::addSymbol(SymbolAssignment *Cmd) {
if (Cmd->Name == ".")
Modified: lld/trunk/ELF/LinkerScript.h
URL: http://llvm.org/viewvc/llvm-project/lld/trunk/ELF/LinkerScript.h?rev=315415&r1=315414&r2=315415&view=diff
==============================================================================
--- lld/trunk/ELF/LinkerScript.h (original)
+++ lld/trunk/ELF/LinkerScript.h Tue Oct 10 19:28:28 2017
@@ -186,7 +186,7 @@ struct PhdrsCommand {
};
class LinkerScript final {
// Temporary state used in processCommands() and assignAddresses()
// that must be reinitialized for each call to the above functions, and must
// not be used outside of the scope of a call to the above functions.
struct AddressState {
@@ -247,7 +247,7 @@ public:
void assignAddresses();
void allocateHeaders(std::vector<PhdrEntry *> &Phdrs);
void addSymbol(SymbolAssignment *Cmd);
- void processCommands(OutputSectionFactory &Factory);
+ void processSectionCommands(OutputSectionFactory &Factory);
// SECTIONS command list.
std::vector<BaseCommand *> SectionCommands;
Modified: lld/trunk/ELF/OutputSections.h
@@ -186,7 +186,7 @@ struct PhdrsCommand {
};
class LinkerScript final {
- // Temporary state used in processCommands() and assignAddresses()
+ // Temporary state used in processSectionCommands() and assignAddresses()
// that must be reinitialized for each call to the above functions, and must
// not be used outside of the scope of a call to the above functions.
URL: http://llvm.org/viewvc/llvm-project/lld/trunk/ELF/OutputSections.h?rev=315415&r1=315414&r2=315415&view=diff
==============================================================================